diff --git a/bundles/core/org.eclipse.smarthome.core.autoupdate/.project b/bundles/core/org.eclipse.smarthome.core.autoupdate/.project
index 17691980b57..b9afcda7388 100644
--- a/bundles/core/org.eclipse.smarthome.core.autoupdate/.project
+++ b/bundles/core/org.eclipse.smarthome.core.autoupdate/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.core.autoupdate
- This is the Auto-Update binding of the open Home Automation Bus (openHAB)
+ This is the Auto-Update binding of Eclipse SmartHome
diff --git a/bundles/core/org.eclipse.smarthome.core.binding.xml/.project b/bundles/core/org.eclipse.smarthome.core.binding.xml/.project
index 213e1cfa139..9c7913d91b3 100644
--- a/bundles/core/org.eclipse.smarthome.core.binding.xml/.project
+++ b/bundles/core/org.eclipse.smarthome.core.binding.xml/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.core.binding.xml
- This is the runtime binding XML component of the open Home Automation Bus (openHAB)
+ This is the runtime binding XML component of Eclipse SmartHome
diff --git a/bundles/core/org.eclipse.smarthome.core.persistence/.project b/bundles/core/org.eclipse.smarthome.core.persistence/.project
index 01c66f00537..2d4e71985d7 100644
--- a/bundles/core/org.eclipse.smarthome.core.persistence/.project
+++ b/bundles/core/org.eclipse.smarthome.core.persistence/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.core.persistence
- This is the persistence component of the open Home Automation Bus (openHAB)
+ This is the persistence component of Eclipse SmartHome
diff --git a/bundles/core/org.eclipse.smarthome.core.persistence/src/main/java/org/eclipse/smarthome/core/persistence/PersistenceService.java b/bundles/core/org.eclipse.smarthome.core.persistence/src/main/java/org/eclipse/smarthome/core/persistence/PersistenceService.java
index 30e23323565..10b36b6a29d 100644
--- a/bundles/core/org.eclipse.smarthome.core.persistence/src/main/java/org/eclipse/smarthome/core/persistence/PersistenceService.java
+++ b/bundles/core/org.eclipse.smarthome.core.persistence/src/main/java/org/eclipse/smarthome/core/persistence/PersistenceService.java
@@ -12,7 +12,7 @@
import org.eclipse.smarthome.core.items.Item;
/**
- * A persistence service which can be used to store data from openHAB.
+ * A persistence service which can be used to store data from Eclipse SmartHome.
* This must not necessarily be a local database, a persistence service
* can also be cloud-based or a simply data-export facility (e.g.
* for sending data to an IoT (Internet of Things) service.
diff --git a/bundles/core/org.eclipse.smarthome.core.persistence/src/main/java/org/eclipse/smarthome/core/persistence/QueryablePersistenceService.java b/bundles/core/org.eclipse.smarthome.core.persistence/src/main/java/org/eclipse/smarthome/core/persistence/QueryablePersistenceService.java
index 9986f28527d..5eba9f02e90 100644
--- a/bundles/core/org.eclipse.smarthome.core.persistence/src/main/java/org/eclipse/smarthome/core/persistence/QueryablePersistenceService.java
+++ b/bundles/core/org.eclipse.smarthome.core.persistence/src/main/java/org/eclipse/smarthome/core/persistence/QueryablePersistenceService.java
@@ -13,7 +13,7 @@
/**
* A queryable persistence service which can be used to store and retrieve
- * data from openHAB. This is most likely some kind of database system.
+ * data from Eclipse SmartHome. This is most likely some kind of database system.
*
* @author Kai Kreuzer - Initial contribution and API
* @author Chris Jackson - Added getItems method
diff --git a/bundles/core/org.eclipse.smarthome.core.scheduler/.project b/bundles/core/org.eclipse.smarthome.core.scheduler/.project
index 2d8c1110572..d8e628da28f 100644
--- a/bundles/core/org.eclipse.smarthome.core.scheduler/.project
+++ b/bundles/core/org.eclipse.smarthome.core.scheduler/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.core.scheduler
- This is the Scheduler bundle of the open Home Automation Bus (openHAB)
+ This is the Scheduler bundle of Eclipse SmartHome
diff --git a/bundles/core/org.eclipse.smarthome.core.test/META-INF/MANIFEST.MF b/bundles/core/org.eclipse.smarthome.core.test/META-INF/MANIFEST.MF
index 9dcee627703..503d1222e3f 100644
--- a/bundles/core/org.eclipse.smarthome.core.test/META-INF/MANIFEST.MF
+++ b/bundles/core/org.eclipse.smarthome.core.test/META-INF/MANIFEST.MF
@@ -1,6 +1,6 @@
Manifest-Version: 1.0
Bundle-ManifestVersion: 2
-Bundle-Name: Tests for the openHAB Core
+Bundle-Name: Tests for the Eclipse SmartHome Core
Bundle-SymbolicName: org.eclipse.smarthome.core.test
Bundle-Version: 0.9.0.qualifier
Bundle-Vendor: Eclipse.org/SmartHome
diff --git a/bundles/core/org.eclipse.smarthome.core.thing.test/src/test/groovy/org/eclipse/smarthome/core/thing/binding/BindingBaseClassesOSGiTest.groovy b/bundles/core/org.eclipse.smarthome.core.thing.test/src/test/groovy/org/eclipse/smarthome/core/thing/binding/BindingBaseClassesOSGiTest.groovy
index 95c6331d4f0..10f5178ce25 100644
--- a/bundles/core/org.eclipse.smarthome.core.thing.test/src/test/groovy/org/eclipse/smarthome/core/thing/binding/BindingBaseClassesOSGiTest.groovy
+++ b/bundles/core/org.eclipse.smarthome.core.thing.test/src/test/groovy/org/eclipse/smarthome/core/thing/binding/BindingBaseClassesOSGiTest.groovy
@@ -5,15 +5,6 @@
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*/
-
-
-/**
- * Copyright (c) 2014-2015 openHAB UG (haftungsbeschraenkt) and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- */
package org.eclipse.smarthome.core.thing.binding
import static org.hamcrest.CoreMatchers.*
diff --git a/bundles/core/org.eclipse.smarthome.core.thing.xml/.project b/bundles/core/org.eclipse.smarthome.core.thing.xml/.project
index cff213f6024..51bc30a608b 100644
--- a/bundles/core/org.eclipse.smarthome.core.thing.xml/.project
+++ b/bundles/core/org.eclipse.smarthome.core.thing.xml/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.core.thing.xml
- This is the runtime Thing XML component of the open Home Automation Bus (openHAB)
+ This is the runtime Thing XML component of Eclipse SmartHome
diff --git a/bundles/core/org.eclipse.smarthome.core.thing/.project b/bundles/core/org.eclipse.smarthome.core.thing/.project
index 06dee0af328..4697203edbf 100644
--- a/bundles/core/org.eclipse.smarthome.core.thing/.project
+++ b/bundles/core/org.eclipse.smarthome.core.thing/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.core.thing
- This is the runtime component of the open Home Automation Bus (openHAB)
+ This is the core thing component of Eclipse SmartHome
diff --git a/bundles/core/org.eclipse.smarthome.core.transform/.project b/bundles/core/org.eclipse.smarthome.core.transform/.project
index 8b4b4fc7c0b..56aa957387a 100644
--- a/bundles/core/org.eclipse.smarthome.core.transform/.project
+++ b/bundles/core/org.eclipse.smarthome.core.transform/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.core.transform
- This is the transformation bundle of the open Home Automation Bus (openHAB)
+ This is the transformation bundle of Eclipse SmartHome
diff --git a/bundles/core/org.eclipse.smarthome.core/src/main/java/org/eclipse/smarthome/core/types/TypeParser.java b/bundles/core/org.eclipse.smarthome.core/src/main/java/org/eclipse/smarthome/core/types/TypeParser.java
index 6432a6a0009..adfd1eb7ccd 100644
--- a/bundles/core/org.eclipse.smarthome.core/src/main/java/org/eclipse/smarthome/core/types/TypeParser.java
+++ b/bundles/core/org.eclipse.smarthome.core/src/main/java/org/eclipse/smarthome/core/types/TypeParser.java
@@ -12,7 +12,7 @@
import java.util.List;
/**
- * This is a helper class that helps parsing a string into an openHAB type (state or command).
+ * This is a helper class that helps parsing a string into an Eclipse SmartHome type (state or command).
*
* @author Kai Kreuzer - Initial contribution and API
*
@@ -22,7 +22,8 @@ public final class TypeParser {
/**
* No instances allowed.
*/
- private TypeParser() {}
+ private TypeParser() {
+ }
private static final String CORE_LIBRARY_PACKAGE = "org.eclipse.smarthome.core.library.types.";
@@ -55,7 +56,7 @@ public static Type parseType(String typeName, String input) {
* Example: The type list is OnOffType.class,StringType.class. The string "ON" is now accepted by the OnOffType and
* thus OnOffType.ON will be returned (and not a StringType with value "ON").
*
- *
+ *
* @param types possible types of the state to consider
* @param s the string to parse
* @return the corresponding State instance or null
@@ -65,8 +66,9 @@ public static State parseState(List> types, String s) {
try {
Method valueOf = type.getMethod("valueOf", String.class);
State state = (State) valueOf.invoke(type, s);
- if (state != null)
+ if (state != null) {
return state;
+ }
} catch (NoSuchMethodException e) {
} catch (IllegalArgumentException e) {
} catch (IllegalAccessException e) {
@@ -85,7 +87,7 @@ public static State parseState(List> types, String s) {
* Example: The type list is OnOffType.class,StringType.class. The string "ON" is now accepted by the OnOffType and
* thus OnOffType.ON will be returned (and not a StringType with value "ON").
*
- *
+ *
* @param types possible types of the command to consider
* @param s the string to parse
* @return the corresponding Command instance or null
@@ -95,8 +97,9 @@ public static Command parseCommand(List> types, String
try {
Method valueOf = type.getMethod("valueOf", String.class);
Command value = (Command) valueOf.invoke(type, s);
- if (value != null)
+ if (value != null) {
return value;
+ }
} catch (NoSuchMethodException e) {
} catch (IllegalArgumentException e) {
} catch (IllegalAccessException e) {
diff --git a/bundles/io/org.eclipse.smarthome.io.console.eclipse/src/main/java/org/eclipse/smarthome/io/console/eclipse/internal/ConsoleSupportEclipse.java b/bundles/io/org.eclipse.smarthome.io.console.eclipse/src/main/java/org/eclipse/smarthome/io/console/eclipse/internal/ConsoleSupportEclipse.java
index b7c981b7584..92b54f3faca 100644
--- a/bundles/io/org.eclipse.smarthome.io.console.eclipse/src/main/java/org/eclipse/smarthome/io/console/eclipse/internal/ConsoleSupportEclipse.java
+++ b/bundles/io/org.eclipse.smarthome.io.console.eclipse/src/main/java/org/eclipse/smarthome/io/console/eclipse/internal/ConsoleSupportEclipse.java
@@ -24,7 +24,7 @@
import org.eclipse.smarthome.io.console.extensions.ConsoleCommandExtension;
/**
- * This class provides access to openHAB functionality through the OSGi console
+ * This class provides access to Eclipse SmartHome functionality through the OSGi console
* of Equinox. Unfortunately, there these command providers are not standardized
* for OSGi, so we need different implementations for different OSGi containers.
*
diff --git a/bundles/io/org.eclipse.smarthome.io.console/.project b/bundles/io/org.eclipse.smarthome.io.console/.project
index 59a156fa53d..6f2e640d032 100644
--- a/bundles/io/org.eclipse.smarthome.io.console/.project
+++ b/bundles/io/org.eclipse.smarthome.io.console/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.io.console
- This is the runtime component of the open Home Automation Bus (openHAB)
+ This is the console core of Eclipse SmartHome
diff --git a/bundles/io/org.eclipse.smarthome.io.monitor/.project b/bundles/io/org.eclipse.smarthome.io.monitor/.project
index 9725698dc05..2d55f510432 100644
--- a/bundles/io/org.eclipse.smarthome.io.monitor/.project
+++ b/bundles/io/org.eclipse.smarthome.io.monitor/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.io.monitor
- This is the runtime component of the open Home Automation Bus (openHAB)
+ This is the I/O monitor of Eclipse SmartHome
diff --git a/bundles/io/org.eclipse.smarthome.io.rest.core/src/main/java/org/eclipse/smarthome/io/rest/core/persistence/PersistenceResource.java b/bundles/io/org.eclipse.smarthome.io.rest.core/src/main/java/org/eclipse/smarthome/io/rest/core/persistence/PersistenceResource.java
index a6bb5810407..8f4c708df9a 100644
--- a/bundles/io/org.eclipse.smarthome.io.rest.core/src/main/java/org/eclipse/smarthome/io/rest/core/persistence/PersistenceResource.java
+++ b/bundles/io/org.eclipse.smarthome.io.rest.core/src/main/java/org/eclipse/smarthome/io/rest/core/persistence/PersistenceResource.java
@@ -5,14 +5,6 @@
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*/
-/**
-* Copyright (c) 2010-2013, openHAB.org and others.
-*
-* All rights reserved. This program and the accompanying materials
-* are made available under the terms of the Eclipse Public License v1.0
-* which accompanies this distribution, and is available at
-* http://www.eclipse.org/legal/epl-v10.html
-*/
package org.eclipse.smarthome.io.rest.core.persistence;
import java.util.ArrayList;
diff --git a/bundles/io/org.eclipse.smarthome.io.transport.mqtt/src/main/java/org/eclipse/smarthome/io/transport/mqtt/MqttConnectionObserver.java b/bundles/io/org.eclipse.smarthome.io.transport.mqtt/src/main/java/org/eclipse/smarthome/io/transport/mqtt/MqttConnectionObserver.java
index 600bc7c6ec1..667ad32d89a 100644
--- a/bundles/io/org.eclipse.smarthome.io.transport.mqtt/src/main/java/org/eclipse/smarthome/io/transport/mqtt/MqttConnectionObserver.java
+++ b/bundles/io/org.eclipse.smarthome.io.transport.mqtt/src/main/java/org/eclipse/smarthome/io/transport/mqtt/MqttConnectionObserver.java
@@ -5,13 +5,6 @@
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*/
-/**
-w * Copyright (c) 2014-2015 openHAB UG (haftungsbeschraenkt) and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- */
package org.eclipse.smarthome.io.transport.mqtt;
/**
diff --git a/bundles/model/org.eclipse.smarthome.model.item/META-INF/MANIFEST.MF b/bundles/model/org.eclipse.smarthome.model.item/META-INF/MANIFEST.MF
index 3ef1d8805c3..5fb7d2edcc1 100644
--- a/bundles/model/org.eclipse.smarthome.model.item/META-INF/MANIFEST.MF
+++ b/bundles/model/org.eclipse.smarthome.model.item/META-INF/MANIFEST.MF
@@ -1,7 +1,7 @@
Manifest-Version: 1.0
Bundle-ManifestVersion: 2
Bundle-Name: Eclipse SmartHome Item Model
-Bundle-Vendor: openHABorg
+Bundle-Vendor: Eclipse.org/SmartHome
Bundle-Version: 0.9.0.qualifier
Bundle-SymbolicName: org.eclipse.smarthome.model.item;singleton:=true
Require-Bundle: org.eclipse.xtext,
diff --git a/bundles/model/org.eclipse.smarthome.model.rule.runtime/src/org/eclipse/smarthome/model/rule/runtime/internal/engine/RuleEngineImpl.java b/bundles/model/org.eclipse.smarthome.model.rule.runtime/src/org/eclipse/smarthome/model/rule/runtime/internal/engine/RuleEngineImpl.java
index a6b3d433c95..15c04556648 100644
--- a/bundles/model/org.eclipse.smarthome.model.rule.runtime/src/org/eclipse/smarthome/model/rule/runtime/internal/engine/RuleEngineImpl.java
+++ b/bundles/model/org.eclipse.smarthome.model.rule.runtime/src/org/eclipse/smarthome/model/rule/runtime/internal/engine/RuleEngineImpl.java
@@ -53,7 +53,7 @@
import com.google.inject.Injector;
/**
- * This class is the core of the openHAB rule engine.
+ * This class is the core of the Eclipse SmartHome rule engine.
* It listens to changes to the rules folder, evaluates the trigger conditions of the rules and
* schedules them for execution dependent on their triggering conditions.
*
@@ -342,8 +342,8 @@ protected synchronized void executeRules(Iterable rules, State oldState) {
}
/**
- * we need to be able to deactivate the rule execution, otherwise the openHAB designer
- * would also execute the rules.
+ * we need to be able to deactivate the rule execution, otherwise the Eclipse SmartHome designer would also execute
+ * the rules.
*
* @return true, if rules should be executed, false otherwise
*/
diff --git a/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/actions/BusEvent.java b/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/actions/BusEvent.java
index bd495bfdf89..afadbc3c8e3 100644
--- a/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/actions/BusEvent.java
+++ b/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/actions/BusEvent.java
@@ -26,7 +26,7 @@
/**
* The static methods of this class are made available as functions in the scripts.
- * This gives direct write access to the openHAB event bus from within scripts.
+ * This gives direct write access to the Eclipse SmartHome event bus from within scripts.
* Items should not be updated directly (setting the state property), but updates should
* be sent to the bus, so that all interested bundles are notified.
*
diff --git a/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/engine/Script.java b/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/engine/Script.java
index 9e06042fd0d..4930fd79504 100644
--- a/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/engine/Script.java
+++ b/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/engine/Script.java
@@ -10,7 +10,7 @@
import org.eclipse.xtext.xbase.interpreter.IEvaluationContext;
/**
- * This interface is implemented by openHAB scripts.
+ * This interface is implemented by Eclipse SmartHome scripts.
*
* @author Kai Kreuzer - Initial contribution and API
*
@@ -22,7 +22,7 @@ public interface Script {
/**
* Executes the script instance and returns the execution result
- *
+ *
* @return the execution result or null
, if the script does not have a return value
* @throws ScriptExecutionException if an error occurs during the execution
*/
@@ -30,7 +30,7 @@ public interface Script {
/**
* Executes the script instance with a given evaluation context and returns the execution result
- *
+ *
* @param evaluationContext the evaluation context is a map of variables (name, object)
* that should be available during the script execution
* @return the execution result or null
, if the script does not have a return value
diff --git a/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/engine/ScriptEngine.java b/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/engine/ScriptEngine.java
index f3d013246c2..8ad0556b57b 100644
--- a/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/engine/ScriptEngine.java
+++ b/bundles/model/org.eclipse.smarthome.model.script/src/org/eclipse/smarthome/model/script/engine/ScriptEngine.java
@@ -10,8 +10,8 @@
import org.eclipse.xtext.xbase.XExpression;
/**
- * The script engine is the main entrypoint for openHAB script use. It can build {@link Script} instances
- * from simple strings. These scripts can then be executed by the caller.
+ * The script engine is the main entrypoint for Eclipse SmartHome script use. It can build {@link Script} instances from
+ * simple strings. These scripts can then be executed by the caller.
*
* @author Kai Kreuzer - Initial contribution and API
*
diff --git a/bundles/storage/org.eclipse.smarthome.storage.json.test/META-INF/MANIFEST.MF b/bundles/storage/org.eclipse.smarthome.storage.json.test/META-INF/MANIFEST.MF
index 959da09b155..9b8bcefe1a0 100644
--- a/bundles/storage/org.eclipse.smarthome.storage.json.test/META-INF/MANIFEST.MF
+++ b/bundles/storage/org.eclipse.smarthome.storage.json.test/META-INF/MANIFEST.MF
@@ -1,6 +1,6 @@
Manifest-Version: 1.0
Bundle-ManifestVersion: 2
-Bundle-Name: Tests for the openHAB Json Storage
+Bundle-Name: Tests for the Eclipse SmartHome Json Storage
Bundle-SymbolicName: org.eclipse.smarthome.storage.json.test
Bundle-Version: 0.9.0.qualifier
Bundle-Vendor: Eclipse.org/SmartHome
diff --git a/bundles/storage/org.eclipse.smarthome.storage.json/META-INF/MANIFEST.MF b/bundles/storage/org.eclipse.smarthome.storage.json/META-INF/MANIFEST.MF
index 94a6e1d482c..88c58fc80cd 100644
--- a/bundles/storage/org.eclipse.smarthome.storage.json/META-INF/MANIFEST.MF
+++ b/bundles/storage/org.eclipse.smarthome.storage.json/META-INF/MANIFEST.MF
@@ -1,6 +1,6 @@
Manifest-Version: 1.0
Bundle-Name: Eclipse SmartHome Json Storage Service
-Bundle-Vendor: openHAB.org
+Bundle-Vendor: Eclipse.org/SmartHome
Bundle-Version: 0.9.0.qualifier
Bundle-ManifestVersion: 2
Bundle-License: http://www.eclipse.org/legal/epl-v10.html
@@ -18,7 +18,6 @@ Import-Package: com.google.gson,
org.osgi.service.event,
org.slf4j
Bundle-SymbolicName: org.eclipse.smarthome.storage.json;singleton:=true
-Bundle-DocURL: http://www.openhab.org
Bundle-RequiredExecutionEnvironment: JavaSE-1.7
Bundle-ClassPath: .
Service-Component: OSGI-INF/*.xml
diff --git a/bundles/storage/org.eclipse.smarthome.storage.mapdb.test/META-INF/MANIFEST.MF b/bundles/storage/org.eclipse.smarthome.storage.mapdb.test/META-INF/MANIFEST.MF
index 2a7dd01f7ee..e7796fa6393 100644
--- a/bundles/storage/org.eclipse.smarthome.storage.mapdb.test/META-INF/MANIFEST.MF
+++ b/bundles/storage/org.eclipse.smarthome.storage.mapdb.test/META-INF/MANIFEST.MF
@@ -1,6 +1,6 @@
Manifest-Version: 1.0
Bundle-ManifestVersion: 2
-Bundle-Name: Tests for the openHAB MapDB Storage
+Bundle-Name: Tests for the Eclipse SmartHome MapDB Storage
Bundle-SymbolicName: org.eclipse.smarthome.storage.mapdb.test
Bundle-Version: 0.9.0.qualifier
Bundle-Vendor: Eclipse.org/SmartHome
diff --git a/bundles/storage/org.eclipse.smarthome.storage.mapdb/META-INF/MANIFEST.MF b/bundles/storage/org.eclipse.smarthome.storage.mapdb/META-INF/MANIFEST.MF
index 804fcf15d23..309d093f1af 100644
--- a/bundles/storage/org.eclipse.smarthome.storage.mapdb/META-INF/MANIFEST.MF
+++ b/bundles/storage/org.eclipse.smarthome.storage.mapdb/META-INF/MANIFEST.MF
@@ -1,6 +1,6 @@
Manifest-Version: 1.0
Bundle-Name: Eclipse SmartHome MapDB Storage Service
-Bundle-Vendor: openHAB.org
+Bundle-Vendor: Eclipse.org/SmartHome
Bundle-Version: 0.9.0.qualifier
Bundle-ManifestVersion: 2
Bundle-License: http://www.eclipse.org/legal/epl-v10.html
@@ -18,7 +18,6 @@ Import-Package: com.google.gson,
org.osgi.service.event,
org.slf4j
Bundle-SymbolicName: org.eclipse.smarthome.storage.mapdb;singleton:=true
-Bundle-DocURL: http://www.openhab.org
Bundle-RequiredExecutionEnvironment: JavaSE-1.7
Bundle-ClassPath: .
Service-Component: OSGI-INF/*.xml
diff --git a/bundles/ui/org.eclipse.smarthome.ui/.project b/bundles/ui/org.eclipse.smarthome.ui/.project
index f9456168f75..27c2763750b 100644
--- a/bundles/ui/org.eclipse.smarthome.ui/.project
+++ b/bundles/ui/org.eclipse.smarthome.ui/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.ui
- This is the runtime ui component of the open Home Automation Bus (openHAB)
+ This is the runtime UI component of Eclipse SmartHome
diff --git a/bundles/ui/org.eclipse.smarthome.ui/src/main/java/org/eclipse/smarthome/ui/internal/proxy/ProxyServlet.java b/bundles/ui/org.eclipse.smarthome.ui/src/main/java/org/eclipse/smarthome/ui/internal/proxy/ProxyServlet.java
index 455ad1f191f..6e819e359c7 100644
--- a/bundles/ui/org.eclipse.smarthome.ui/src/main/java/org/eclipse/smarthome/ui/internal/proxy/ProxyServlet.java
+++ b/bundles/ui/org.eclipse.smarthome.ui/src/main/java/org/eclipse/smarthome/ui/internal/proxy/ProxyServlet.java
@@ -47,7 +47,7 @@
/**
* The proxy servlet is used by image and video widgets. As its name suggests, it proxies the content, so
- * that it is possible to include resources (images/videos) from the LAN in the openHAB UI. This is
+ * that it is possible to include resources (images/videos) from the LAN in the web UI. This is
* especially useful for webcams as you would not want to make them directly available to the internet.
*
* The servlet registers as "/proxy" and expects the two parameters "sitemap" and "widgetId". It will
@@ -62,8 +62,8 @@
* widgets in your sitemaps.
*
* It is also possible to use credentials in a url, e.g. "http://user:pwd@localserver/image.jpg" -
- * the proxy servlet will be able to access the content and provide it to the openHAB UIs through the
- * standard openHAB authentication mechanism (if enabled).
+ * the proxy servlet will be able to access the content and provide it to the web UIs through the
+ * standard web authentication mechanism (if enabled).
*
* This servlet also supports data streams, such as a webcam video stream etc.
*
diff --git a/distribution/smarthome/conf/items/demo.items b/distribution/smarthome/conf/items/demo.items
deleted file mode 100644
index cec2b1e6d57..00000000000
--- a/distribution/smarthome/conf/items/demo.items
+++ /dev/null
@@ -1,12 +0,0 @@
-Group:Switch:OR(ON,OFF) DemoSwitchGroup [ "home-group" ]
-
-Switch DemoSwitch (DemoSwitchGroup)
-Dimmer DemoDimmer (DemoSwitchGroup)
-Rollershutter DemoRollershutter
-Color DemoColor (DemoSwitchGroup)
-DateTime DemoDateTime
-Location DemoLocation
-String DemoString
-Contact DemoContact
-
-Number Weather_Temperature "Outside Temperature [%.1f °C]" (Weather_Chart) { channel="yahooweather:weather:berlin:temperature" }
diff --git a/distribution/smarthome/conf/persistence/logging.persist b/distribution/smarthome/conf/persistence/logging.persist
deleted file mode 100644
index 83c6ba3c70f..00000000000
--- a/distribution/smarthome/conf/persistence/logging.persist
+++ /dev/null
@@ -1,15 +0,0 @@
-// persistence strategies have a name and a definition and are referred to in the "Items" section
-Strategies {
- // if no strategy is specified for an item entry below, the default list will be used
- default = everyChange
-}
-
-/*
- * Each line in this section defines for which item(s) which strategy(ies) should be applied.
- * You can list single items, use "*" for all items or "groupitem*" for all members of a group
- * item (excl. the group item itself).
- */
-Items {
- // log all temperatures on every change
- Temperature* -> "temperatures"
-}
diff --git a/distribution/smarthome/conf/rules/demo.rules b/distribution/smarthome/conf/rules/demo.rules
deleted file mode 100644
index cfb652959c4..00000000000
--- a/distribution/smarthome/conf/rules/demo.rules
+++ /dev/null
@@ -1,9 +0,0 @@
-rule "Initialize demo items"
-when
- System started
-then
- DemoLocation.postUpdate("52,9")
- DemoContact.postUpdate(OPEN)
- DemoString.postUpdate("Hello SmartHome!")
- DemoDateTime.postUpdate(new DateTimeType())
-end
diff --git a/distribution/smarthome/conf/sitemaps/demo.sitemap b/distribution/smarthome/conf/sitemaps/demo.sitemap
deleted file mode 100644
index 00f283d884f..00000000000
--- a/distribution/smarthome/conf/sitemaps/demo.sitemap
+++ /dev/null
@@ -1,14 +0,0 @@
-sitemap demo label="Demo Sitemap" {
- Frame label="Demo Items" {
- Text item=DemoContact label="Contact [MAP(en.map):%s]"
- Text item=DemoString label="Message [%s]"
- Text item=DemoDateTime label="Date [%1$tA, %1$td.%1$tm.%1$tY]"
- Group item=DemoSwitchGroup icon=icon1
- }
- Frame label="Location" {
- Mapview item=DemoLocation height=10
- }
- Frame label="Weather" {
- Text item=Weather_Temperature
- }
-}
diff --git a/distribution/smarthome/conf/things/demo.things b/distribution/smarthome/conf/things/demo.things
deleted file mode 100644
index b8b29b4b7f5..00000000000
--- a/distribution/smarthome/conf/things/demo.things
+++ /dev/null
@@ -1,3 +0,0 @@
-yahooweather:weather:berlin [ location=638242 ]
-yahooweather:weather:losangeles "Los Angeles" [ location=2442047, refresh=120 ]
-
diff --git a/docs/documentation/development/testing.md b/docs/documentation/development/testing.md
index df3ab75ba4c..9a264467efb 100644
--- a/docs/documentation/development/testing.md
+++ b/docs/documentation/development/testing.md
@@ -15,7 +15,7 @@ In OSGi tests are implemented in a separate fragment bundle, which host is the b
Manifest-Version: 1.0
Bundle-ManifestVersion: 2
- Bundle-Name: Tests for the openHAB Core
+ Bundle-Name: Tests for the Eclipse SmartHome Core
Bundle-SymbolicName: org.eclipse.smarthome.core.test
Bundle-Version: 0.9.0.qualifier
Bundle-Vendor: Eclipse.org/SmartHome
diff --git a/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMBridgeMDNSDiscovery.xml b/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMBridgeMDNSDiscovery.xml
index 76dad4b114f..fce641fe231 100644
--- a/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMBridgeMDNSDiscovery.xml
+++ b/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMBridgeMDNSDiscovery.xml
@@ -8,13 +8,10 @@
http://www.eclipse.org/legal/epl-v10.html
-->
-
-
+
diff --git a/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMChannelTypeProvider.xml b/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMChannelTypeProvider.xml
index 6f3e6145e58..7459e7a686e 100644
--- a/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMChannelTypeProvider.xml
+++ b/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMChannelTypeProvider.xml
@@ -8,9 +8,6 @@
http://www.eclipse.org/legal/epl-v10.html
-->
-
diff --git a/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMHandlerFactory.xml b/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMHandlerFactory.xml
index 5f63fb4a55e..8f690e83db7 100644
--- a/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMHandlerFactory.xml
+++ b/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/OSGI-INF/DigitalSTROMHandlerFactory.xml
@@ -8,9 +8,6 @@
http://www.eclipse.org/legal/epl-v10.html
-->
-
diff --git a/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/src/main/java/org/eclipse/smarthome/binding/digitalstrom/internal/lib/structure/scene/sceneEvent/EventItem.java b/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/src/main/java/org/eclipse/smarthome/binding/digitalstrom/internal/lib/structure/scene/sceneEvent/EventItem.java
index d7d0e7d21c8..0a439d28860 100644
--- a/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/src/main/java/org/eclipse/smarthome/binding/digitalstrom/internal/lib/structure/scene/sceneEvent/EventItem.java
+++ b/extensions/binding/org.eclipse.smarthome.binding.digitalstrom/src/main/java/org/eclipse/smarthome/binding/digitalstrom/internal/lib/structure/scene/sceneEvent/EventItem.java
@@ -8,16 +8,6 @@
package org.eclipse.smarthome.binding.digitalstrom.internal.lib.structure.scene.sceneEvent;
import java.util.HashMap;
-
-/**
- * Copyright (c) 2010-2014, openHAB.org and others.
- *
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- */
-
import java.util.Map;
import org.eclipse.smarthome.binding.digitalstrom.internal.lib.structure.scene.constants.EventPropertyEnum;
diff --git a/extensions/io/org.eclipse.smarthome.io.javasound/src/main/java/org/eclipse/smarthome/io/javasound/internal/JavaSoundInputStream.java b/extensions/io/org.eclipse.smarthome.io.javasound/src/main/java/org/eclipse/smarthome/io/javasound/internal/JavaSoundInputStream.java
index 3537357dc06..1d5bc0987a7 100644
--- a/extensions/io/org.eclipse.smarthome.io.javasound/src/main/java/org/eclipse/smarthome/io/javasound/internal/JavaSoundInputStream.java
+++ b/extensions/io/org.eclipse.smarthome.io.javasound/src/main/java/org/eclipse/smarthome/io/javasound/internal/JavaSoundInputStream.java
@@ -6,13 +6,6 @@
* http://www.eclipse.org/legal/epl-v10.html
*/
package org.eclipse.smarthome.io.javasound.internal;
-/**
- * Copyright (c) 2014-2016 openHAB UG (haftungsbeschraenkt) and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- */
import java.io.IOException;
diff --git a/extensions/ui/org.eclipse.smarthome.ui.classic/.project b/extensions/ui/org.eclipse.smarthome.ui.classic/.project
index 96007cf6dbb..1c071431c8b 100644
--- a/extensions/ui/org.eclipse.smarthome.ui.classic/.project
+++ b/extensions/ui/org.eclipse.smarthome.ui.classic/.project
@@ -1,7 +1,7 @@
org.eclipse.smarthome.ui.classic
- This is the runtime component of the open Home Automation Bus (openHAB)
+ This is the classic UI of Eclipse SmartHome
diff --git a/extensions/ui/org.eclipse.smarthome.ui.paper/web-src/index.html b/extensions/ui/org.eclipse.smarthome.ui.paper/web-src/index.html
index fe0480d890c..9ea1ddb0002 100644
--- a/extensions/ui/org.eclipse.smarthome.ui.paper/web-src/index.html
+++ b/extensions/ui/org.eclipse.smarthome.ui.paper/web-src/index.html
@@ -1,14 +1,4 @@
-
-
diff --git a/features/org.eclipse.smarthome.feature.runtime.automation/feature.xml b/features/org.eclipse.smarthome.feature.runtime.automation/feature.xml
index 3d50c9f32ed..9cb0fbaa7d4 100644
--- a/features/org.eclipse.smarthome.feature.runtime.automation/feature.xml
+++ b/features/org.eclipse.smarthome.feature.runtime.automation/feature.xml
@@ -20,7 +20,7 @@ Automation support
- Copyright (C) 2014-2015 openHAB UG (haftungsbeschränkt) and others
+ Copyright (c) 2014-2016 by the respective copyright holders.
diff --git a/features/org.eclipse.smarthome.feature.runtime.binding/feature.xml b/features/org.eclipse.smarthome.feature.runtime.binding/feature.xml
index 2d2f971f15d..3c00f94c855 100644
--- a/features/org.eclipse.smarthome.feature.runtime.binding/feature.xml
+++ b/features/org.eclipse.smarthome.feature.runtime.binding/feature.xml
@@ -19,7 +19,7 @@
- Copyright (C) 2014 openHAB UG (haftungsbeschränkt) and others
+ Copyright (c) 2014-2016 by the respective copyright holders.
diff --git a/features/org.eclipse.smarthome.feature.runtime.console.equinox/feature.xml b/features/org.eclipse.smarthome.feature.runtime.console.equinox/feature.xml
index 65394277865..6f39afe6d3f 100644
--- a/features/org.eclipse.smarthome.feature.runtime.console.equinox/feature.xml
+++ b/features/org.eclipse.smarthome.feature.runtime.console.equinox/feature.xml
@@ -19,7 +19,7 @@
- Copyright (C) 2015 openHAB UG (haftungsbeschränkt) and others
+ Copyright (c) 2014-2016 by the respective copyright holders.
diff --git a/features/org.eclipse.smarthome.feature.runtime.console.rfc147/feature.xml b/features/org.eclipse.smarthome.feature.runtime.console.rfc147/feature.xml
index dbca44a0f00..cd187e341fb 100644
--- a/features/org.eclipse.smarthome.feature.runtime.console.rfc147/feature.xml
+++ b/features/org.eclipse.smarthome.feature.runtime.console.rfc147/feature.xml
@@ -19,7 +19,7 @@
- Copyright (C) 2015 openHAB UG (haftungsbeschränkt) and others
+ Copyright (c) 2014-2016 by the respective copyright holders.
diff --git a/features/org.eclipse.smarthome.feature.runtime.model/feature.xml b/features/org.eclipse.smarthome.feature.runtime.model/feature.xml
index b5c161dd6d8..73fa5342133 100644
--- a/features/org.eclipse.smarthome.feature.runtime.model/feature.xml
+++ b/features/org.eclipse.smarthome.feature.runtime.model/feature.xml
@@ -20,7 +20,7 @@ Model Support.
- Copyright (C) 2014 openHAB UG (haftungsbeschränkt) and others
+ Copyright (c) 2014-2016 by the respective copyright holders.
diff --git a/features/org.eclipse.smarthome.feature.runtime.ui/feature.xml b/features/org.eclipse.smarthome.feature.runtime.ui/feature.xml
index 8f5367921f8..d505786a90b 100644
--- a/features/org.eclipse.smarthome.feature.runtime.ui/feature.xml
+++ b/features/org.eclipse.smarthome.feature.runtime.ui/feature.xml
@@ -19,7 +19,7 @@
- Copyright (C) 2014-2015 openHAB UG (haftungsbeschränkt) and others
+ Copyright (c) 2014-2016 by the respective copyright holders.
diff --git a/features/org.eclipse.smarthome.feature.test/feature.xml b/features/org.eclipse.smarthome.feature.test/feature.xml
index c5f8f8c601f..ed87ac65b16 100644
--- a/features/org.eclipse.smarthome.feature.test/feature.xml
+++ b/features/org.eclipse.smarthome.feature.test/feature.xml
@@ -19,7 +19,7 @@
- Copyright (C) 2014, openHAB UG (haftungsbeschränkt) and others
+ Copyright (c) 2014-2016 by the respective copyright holders.
diff --git a/bundles/core/org.eclipse.smarthome.core/src/main/java/org/eclipse/smarthome/core/items/Item.java b/bundles/core/org.eclipse.smarthome.core/src/main/java/org/eclipse/smarthome/core/items/Item.java
index 230a43ccc43..a95b6be36ed 100644
--- a/bundles/core/org.eclipse.smarthome.core/src/main/java/org/eclipse/smarthome/core/items/Item.java
+++ b/bundles/core/org.eclipse.smarthome.core/src/main/java/org/eclipse/smarthome/core/items/Item.java
@@ -11,6 +11,8 @@
import java.util.Locale;
import java.util.Set;
+import org.eclipse.smarthome.core.library.types.OnOffType;
+import org.eclipse.smarthome.core.library.types.PercentType;
import org.eclipse.smarthome.core.types.Command;
import org.eclipse.smarthome.core.types.State;
import org.eclipse.smarthome.core.types.StateDescription;
@@ -18,7 +20,7 @@
/**
*
* This interface defines the core features of an openHAB item.
*
*
* Item instances are used for all stateful services and are especially important for the {@link ItemRegistry}.
@@ -31,14 +33,14 @@ public interface Item {
/**
* returns the current state of the item
- *
+ *
* @return the current state
*/
public State getState();
/**
* returns the current state of the item as a specific type
- *
+ *
* @return the current state in the requested type or
* null, if state cannot be provided as the requested type
*/
@@ -46,14 +48,14 @@ public interface Item {
/**
* returns the name of the item
- *
+ *
* @return the name of the item
*/
public String getName();
/**
* returns the item type as defined by {@link ItemFactory}s
- *
+ *
* @return the item type
*/
public String getType();
@@ -66,13 +68,14 @@ public interface Item {
* Imagine e.g. a dimmer device: It's status could be 0%, 10%, 50%, 100%, but also OFF or ON and maybe UNDEFINED. So
* the accepted data types would be in this case {@link PercentType}, {@link OnOffType} and {@link UnDefType}
*
- *
+ *
*
* The order of data types denotes the order of preference. So in case a state needs to be converted
* in order to be accepted, it will be attempted to convert it to a type from top to bottom. Therefore
* the type with the least information loss should be on top of the list - in the example above the
* {@link PercentType} carries more information than the {@link OnOffType}, hence it is listed first.
*
+ *
* @return a list of data types that can be used to update the item state
*/
public List> getAcceptedDataTypes();
@@ -85,21 +88,21 @@ public interface Item {
* Imagine e.g. a dimmer device: You could ask it to dim to 0%, 10%, 50%, 100%, but also to turn OFF or ON. So the
* accepted command types would be in this case {@link PercentType}, {@link OnOffType}
*
- *
+ *
* @return a list of all command types that can be used for this item
*/
public List> getAcceptedCommandTypes();
/**
* Returns a list of the names of the groups this item belongs to.
- *
+ *
* @return list of item group names
*/
public List getGroupNames();
/**
* Returns a set of tags. If the item is not tagged, an empty set is returned.
- *
+ *
* @return set of tags.
*/
public Set getTags();
@@ -113,7 +116,7 @@ public interface Item {
/**
* Returns true if the item's tags contains the specific tag, otherwise false.
- *
+ *
* @param tag - a tag whose presence in the item's tags is to be tested.
* @return true if the item's tags contains the specific tag, otherwise false.
*/
@@ -18,7 +20,7 @@
/**
*
- * This interface defines the core features of an openHAB item.
+ * This interface defines the core features of an Eclipse SmartHome item.
*
*